<?php
namespace Claromentis\Mailgun\Model;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"] ?: array()) + array("_d706c160e4" . "5bf7434fff8" . "2a5976f0e19" => base64_decode("YXJyYXlfa2V5cw" . "=="), "_956cd32" . "298a229f" . "9768f109" . "6f077ace" . "3" => base64_decode("Ym9keS1wbGFpbg=" . "="), "_a1e707d02a236dadebd15a4" . "5e65ebdb6" => base64_decode("YXR0YWNobWVudC1jb3Vud" . "A=="), "_97ea09a7faf27c52c6eff69773df1" . "d8a" => base64_decode("dGltZXN0YW1" . "w"), "_9c050c786fc87" . "170cbb84fc6a8b" . "13cb6" => base64_decode("YXR0YWNobWV" . "udC0="), "_8c575917cbaedf" . "1e7efae84939402" . "bff" => base64_decode("U3ViamVj" . "dA=="), "_1d6c68a0262e8f" . "a0bed1215b7224a" . "98e" => base64_decode("cmVjaXBpZW" . "50"), "_618a4aeb9fecc459" . "2a4521f34876fa29" => base64_decode("ZnJ" . "vbQ" . "=="), "_44e986c04f41a08b56a383c" . "7b3a88ee2" => base64_decode("c2VuZG" . "Vy"), "_6e1c717" . "cf3cbf1a" . "f982ed74" . "d4336b7f" . "1" => base64_decode("Ym9k" . "eS1o" . "dG1s"), "_f589476007fa133f457c3ef29ddfa5" . "66" => base64_decode("V" . "G" . "8" . "="), "_f39f5346e313" . "e4dd1ac3a7bd8" . "032beda" => base64_decode("c3Vic3R" . "yX2NvbX" . "BhcmU="));
use Claromentis\Core\Mail\Receive\Contract\MailAttachment;
use Claromentis\Core\Mail\Receive\Contract\MailMessage;
use Claromentis\Core\Util\ArrayUtil;




class MailgunMessage implements MailMessage
{
    protected $message_data;
    protected $attachments_data;
    protected $attachments;
    
    
    
    
    
    public function __construct($_a3d82c5df38e194c9c73e3ccb4223bbc = [], $_4e7ab34a53ffb13eb0838003f33034d4 = [])
    {
        $this->message_data = $_a3d82c5df38e194c9c73e3ccb4223bbc;
        $this->attachments = $_4e7ab34a53ffb13eb0838003f33034d4;
        foreach ($GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_d706c160e45bf7434fff82a597" . "6f0e19"]($this->message_data) as $key) {
            if ($key !== $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_a1e707d02a236dadebd15a45e6" . "5ebdb6"] && $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_f39f5346e313e4dd1ac3a7bd8032bed" . "a"]($key, $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_9c050c786fc87170" . "cbb84fc6a8b13cb6"], 0, 11) === 0) {
                $this->attachments[] = new MailgunAttachmentString($key, $this->message_data[$key]);
            }
        }
    }
    
    
    
    
    public function GetRecipientAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_1d6c68a0262e8fa" . "0bed1215b7224a98" . "e"]);
    }
    
    
    
    
    
    
    public function GetFrom() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_618a4aeb9fecc459" . "2a4521f34876fa29"]], null);
    }
    
    
    
    
    
    
    
    public function GetTo() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_f589476007fa133f457c3ef" . "29ddfa566"]], null);
    }
    
    
    
    
    public function GetSubject() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_8c575917cbaedf1e7efae849394" . "02bff"]);
    }
    
    
    
    
    public function GetBodyHtml() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_6e1c717cf3" . "cbf1af982ed" . "74d4336b7f1"]);
    }
    
    
    
    
    public function GetBodyText() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_956cd32298a2" . "29f9768f1096f" . "077ace3"]);
    }
    
    
    
    
    public function GetDate() : \Date
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = new \Date(ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_97ea09a7faf27c52c6eff" . "69773df1d8a"]));
        return $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    
    
    
    
    public function GetSenderAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_44e986c04f41a" . "08b56a383c7b3a" . "88ee2"]);
    }
    public function GetAttachments()
    {
        return $this->attachments;
    }
}